@@ -49,8 +49,8 @@ from zope.event import notify
 from zope.server.taskthreads import ThreadedTaskDispatcher
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.i18n.interfaces import IUserPreferredLanguages
-from zope.app.wsgi import WSGIPublisherApplication
 from zope.app.server.main import run
+from zope.app.server.wsgi import http
 from zope.app.appsetup import DatabaseOpened, ProcessStarting
 from zope.app.publication.zopepublication import ZopePublication
 from zope.traversing.interfaces import IContainmentRoot
@@ -64,9 +64,6 @@ from zope.intid import IntIds
 from zope.intid.interfaces import IIntIds
 from zope.component.interfaces import ISite
 from zope.site import LocalSiteManager
-from zope.server.http.wsgihttpserver import WSGIHTTPServer
-from zope.server.http.commonaccesslogger import CommonAccessLogger
-from zope.app.server.wsgi import ServerType
 
 from schooltool.app.interfaces import ApplicationStartUpEvent
 from schooltool.app.interfaces import ApplicationInitializationEvent
@@ -94,12 +91,6 @@ _ = lambda us: catalog.ugettext(us).encode(locale_charset, 'replace')
 _._domain = 'schooltool'
 
 
-schooltool_server = ServerType(WSGIHTTPServer,
-                               WSGIPublisherApplication,
-                               CommonAccessLogger,
-                               8080, True)
-
-
 class Options(object):
     config_filename = 'schooltool.conf'
     daemon = False
@@ -466,7 +457,7 @@ def get_schooltool_plugin_configurations():
 plugin_configurations = get_schooltool_plugin_configurations()
 
 
-class StandaloneServer(object):
+class SchoolToolServer(object):
 
     ZCONFIG_SCHEMA = os.path.join(os.path.dirname(__file__),
                                   'config-schema.xml')
@@ -651,19 +642,6 @@ class StandaloneServer(object):
         app['persons'].super_user = manager
         setSite(None)
 
-    def main(self, argv=sys.argv):
-        """Start the SchoolTool server."""
-        t0, c0 = time.time(), time.clock()
-        options = self.load_options(argv)
-        db = self.setup(options)
-        if not options.manage:
-            self.beforeRun(options, db)
-            t1, c1 = time.time(), time.clock()
-            print _("Startup time: %.3f sec real, %.3f sec CPU") % (t1 - t0,
-                                                                    c1 - c0)
-            run()
-            self.afterRun(options)
-
     def setup(self, options):
         """Configure SchoolTool."""
         setUpLogger(None, options.config.error_log_file,
@@ -675,8 +653,6 @@ class StandaloneServer(object):
         logging.getLogger('ZODB.lock_file').disabled = True
 
         # Process ZCML
-        global SCHOOLTOOL_SITE_DEFINITION
-        SCHOOLTOOL_SITE_DEFINITION = options.config.site_definition
         self.siteConfigFile = options.config.site_definition
         self.configure(options)
 
@@ -726,35 +702,13 @@ class StandaloneServer(object):
 
         return db
 
-    def beforeRun(self, options, db):
-        if options.daemon:
-            daemonize()
-
-        task_dispatcher = ThreadedTaskDispatcher()
-        task_dispatcher.setThreadCount(options.config.thread_pool_size)
-
-        for ip, port in options.config.web:
-            server = schooltool_server.create('HTTP', task_dispatcher, db,
-                                              port=port, ip=ip)
-
-        notify(ProcessStarting())
-
-        if options.config.pid_file:
-            pidfile = file(options.config.pid_file, "w")
-            print >> pidfile, os.getpid()
-            pidfile.close()
-
-    def afterRun(self, options):
-        if options.config.pid_file:
-            os.unlink(options.config.pid_file)
-
-    def configureReportlab(self, fontdir):
+    def configureReportlab(self, fontdirs):
         """Configure reportlab given a path to TrueType fonts.
 
         Disables PDF support in SchoolTool if fontdir is empty.
         Outputs a warning to stderr in case of errors.
         """
-        if not fontdir:
+        if not fontdirs:
             return
 
         try:
@@ -764,20 +718,68 @@ class StandaloneServer(object):
                                    " library.\nPDF support disabled.")
             return
 
-        if not os.path.isdir(fontdir):
-            print >> sys.stderr, (_("Warning: font directory '%s' does"
+        existing_directories = []
+        for fontdir in fontdirs.split(':'):
+            if os.path.isdir(fontdir):
+                existing_directories.append(fontdir)
+
+        if not existing_directories:
+            print >> sys.stderr, (_("Warning: font directories '%s' do"
                                     " not exist.\nPDF support disabled.")
-                                  % fontdir)
+                                  % fontdirs)
             return
 
         for font_file in pdf.font_map.values():
-            font_path = os.path.join(fontdir, font_file)
-            if not os.path.exists(font_path):
-                print >> sys.stderr, _("Warning: font '%s' does not exist.\n"
-                                       "PDF support disabled.") % font_path
+            font_exists = False
+            for fontdir in existing_directories:
+                font_path = os.path.join(fontdir, font_file)
+                if os.path.exists(font_path):
+                    font_exists = True
+            if not font_exists:
+                print >> sys.stderr, _("Warning: font '%s' does not exist"
+                                       " in the font directories '%s'.\n"
+                                       "PDF support disabled.") % (font_file,
+                                                                   fontdirs)
                 return
 
-        pdf.setUpLiberationFonts(fontdir)
+        pdf.setUpFonts(existing_directories)
+
+        
+class StandaloneServer(SchoolToolServer):
+    
+    def beforeRun(self, options, db):
+        if options.daemon:
+            daemonize()
+
+        task_dispatcher = ThreadedTaskDispatcher()
+        task_dispatcher.setThreadCount(options.config.thread_pool_size)
+
+        for ip, port in options.config.web:
+            server = http.create('HTTP', task_dispatcher, db, port=port, ip=ip)
+
+        notify(ProcessStarting())
+
+        if options.config.pid_file:
+            pidfile = file(options.config.pid_file, "w")
+            print >> pidfile, os.getpid()
+            pidfile.close()
+
+    def main(self, argv=sys.argv):
+        """Start the SchoolTool server."""
+        t0, c0 = time.time(), time.clock()
+        options = self.load_options(argv)
+        db = self.setup(options)
+        if not options.manage:
+            self.beforeRun(options, db)
+            t1, c1 = time.time(), time.clock()
+            print _("Startup time: %.3f sec real, %.3f sec CPU") % (t1 - t0,
+                                                                    c1 - c0)
+            run()
+            self.afterRun(options)
+
+    def afterRun(self, options):
+        if options.config.pid_file:
+            os.unlink(options.config.pid_file)
 
 
 def main():
