@@ -22,7 +22,9 @@ Contact objects
 """
 from persistent import Persistent
 
-from zope.component import adapter
+from zope.catalog.text import TextIndex
+from zope.component import adapter, adapts
+from zope.index.text.interfaces import ISearchableText
 from zope.interface import implementer
 from zope.interface import implements
 from zope.intid.interfaces import IIntIds
@@ -45,7 +47,7 @@ from schooltool.relationship.relationship import RelationshipProperty
 from schooltool.relationship.relationship import RelationshipSchema
 from schooltool.securitypolicy import crowds
 from schooltool.table.catalog import ConvertingIndex
-from schooltool.table.table import simple_form_key
+from schooltool.common import simple_form_key
 from schooltool.person.interfaces import IPerson
 from schooltool.course.section import PersonInstructorsCrowd
 
@@ -186,18 +188,32 @@ def getContactFormKey(contact):
 
 
 class ContactCatalog(AttributeCatalog):
-    version = '3 - update missing titles because of wrong security'
+    version = '4 - added text index'
     interface = IContact
     attributes = ('first_name', 'last_name', 'title')
 
     def setIndexes(self, catalog):
         super(ContactCatalog, self).setIndexes(catalog)
         catalog['form_keys'] = ConvertingIndex(converter=IUniqueFormKey)
+        catalog['text'] = TextIndex('getSearchableText', ISearchableText, True)
 
 
 getContactCatalog = ContactCatalog.get
 
 
+class SearchableTextContact(object):
+
+    adapts(IContact)
+    implements(ISearchableText)
+
+    def __init__(self, context):
+        self.context = context
+
+    def getSearchableText(self):
+        result = [self.context.first_name, self.context.last_name]
+        return ' '.join(result)
+
+
 class ContactPersonInstructorsCrowd(PersonInstructorsCrowd):
     """Crowd of instructors of any of related persons to this contact."""
 
